@@ -45,6 +45,9 @@
 #include <iostream>
 #endif
 
+#ifdef _MSC_VER
+#define isnan _isnan
+#endif
 // #define BENCHMARK // uncomment to run benchmark
 
 #ifdef BENCHMARK //def _STFDEBUG
@@ -576,6 +579,10 @@ void wxStfGraph::PlotEvents(wxDC& DC) {
 }
 
 void wxStfGraph::DrawCrosshair( wxDC& DC, const wxPen& pen, const wxPen& printPen, int crosshairSize, double xch, double ych) {
+    if (std::isnan(xch) || std::isnan(ych)) {
+        return;
+    }
+
     wxPen chpen = pen;
     if (isPrinted) {
         chpen = printPen;
